# Virtual Workspaces Configuration
### On this page
  * [Prerequisites](https://help.sap.com/docs/leanix/ea/virtual-workspaces-configuration#prerequisites)
  * [Step 1: Define User Groups for Access Control](https://help.sap.com/docs/leanix/ea/virtual-workspaces-configuration#step-1:-define-user-groups-for-access-control)
  * [Step 2: Create Access Control Entities in SAP LeanIX](https://help.sap.com/docs/leanix/ea/virtual-workspaces-configuration#step-2:-create-access-control-entities-in-sap-leanix)
  * [Step 3: Update the SSO Configuration with the Access Control Attribute](https://help.sap.com/docs/leanix/ea/virtual-workspaces-configuration#step-3:-update-the-sso-configuration-with-the-access-control-attribute)
  * [Check the Session Details](https://help.sap.com/docs/leanix/ea/virtual-workspaces-configuration#check-the-session-details)
  * [Check the Profile Details](https://help.sap.com/docs/leanix/ea/virtual-workspaces-configuration#check-the-profile-details)
  * [Step 4: Configure Global Read/Write Settings for New Fact Sheets](https://help.sap.com/docs/leanix/ea/virtual-workspaces-configuration#step-4:-configure-global-read/write-settings-for-new-fact-sheets)
  * [Step 5: Assign Access Control to Existing Fact Sheets](https://help.sap.com/docs/leanix/ea/virtual-workspaces-configuration#step-5:-assign-access-control-to-existing-fact-sheets)


Set up virtual workspaces to manage access for custom user groups
